@@ -64,6 +64,7 @@ QList<QVariant> defaultScheme = QList<QVariant>()
                                 << QVariant(5)             // health dec amt 38
                                 << QVariant(100)           // rope modfier   39
                                 << QVariant(100)           // get away time  40
+                                << QVariant(0)             // world edge     41
                                 ;
 
 AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
@@ -128,6 +129,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
               << "healthdecrease"      // 38
               << "ropepct"             // 39
               << "getawaytime"         // 40
+              << "worldedge"           // 41
               ;
 
     QList<QVariant> proMode;
@@ -173,6 +175,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> shoppa;
@@ -218,6 +221,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> cleanslate;
@@ -263,6 +267,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> minefield;
@@ -308,6 +313,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> barrelmayhem;
@@ -353,6 +359,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> tunnelhogs;
@@ -398,6 +405,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> forts;
@@ -443,6 +451,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> timeless;
@@ -488,6 +497,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(0)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> thinkingportals;
@@ -533,6 +543,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
     QList<QVariant> kingmode;
@@ -578,6 +589,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(5)             // health dec amt 38
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
             ;
 
 
