@@ -6,6 +6,7 @@
 #include <QIcon>
 #include <QModelIndex>
 #include <QSet>
+#include <QFont>
 
 class PlayersListModel : public QAbstractListModel
 {
@@ -19,7 +20,9 @@ public:
         Registered  = Qt::UserRole + 3,
         Friend      = Qt::UserRole + 4,
         Ignore      = Qt::UserRole + 5,
-        InGame      = Qt::UserRole + 6
+        InGame      = Qt::UserRole + 6,
+        InRoom      = Qt::UserRole + 7,
+        Contributor = Qt::UserRole + 8
     };
 
     enum SpecialRoles {
@@ -40,6 +43,8 @@ public:
     bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex());
     bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex());
 
+    QModelIndex nicknameIndex(const QString & nickname);
+
 public slots:
     void addPlayer(const QString & nickname, bool notify);
     void removePlayer(const QString & nickname, const QString & msg = QString());
@@ -61,12 +66,15 @@ private:
     QList<DataEntry> m_data;
     QSet<QString> m_friendsSet, m_ignoredSet;
     QString m_nickname;
+    QFont m_fontInRoom;
 
     void updateIcon(const QModelIndex & index);
     void updateSortData(const QModelIndex & index);
     void loadSet(QSet<QString> & set, const QString & suffix);
     void saveSet(const QSet<QString> & set, const QString & suffix);
     void checkFriendIgnore(const QModelIndex & mi);
+    bool isFriend(const QString & nickname);
+    bool isIgnored(const QString & nickname);
 };
 
 #endif // PLAYERSLISTMODEL_H
