@@ -19,6 +19,7 @@
 #include <QGridLayout>
 #include <QPushButton>
 #include <QComboBox>
+#include <QLabel>
 
 #include "pagecampaign.h"
 
@@ -31,18 +32,43 @@ QLayout * PageCampaign::bodyLayoutDefinition()
     pageLayout->setRowStretch(0, 1);
     pageLayout->setRowStretch(3, 1);
 
+    QGridLayout * infoLayout = new QGridLayout();
+    infoLayout->setColumnStretch(0, 1);
+    infoLayout->setColumnStretch(1, 1);
+    infoLayout->setColumnStretch(2, 1);
+    infoLayout->setColumnStretch(3, 1);
+    infoLayout->setColumnStretch(4, 1);
+    infoLayout->setRowStretch(0, 1);
+    infoLayout->setRowStretch(1, 1);
+
+    // set this as default image first time page is created, this will change in hwform.cpp
+    btnPreview = formattedButton(":/res/campaign/A_Classic_Fairytale/first_blood.png", true);
+    infoLayout->setAlignment(btnPreview, Qt::AlignHCenter | Qt::AlignVCenter);
+
+    lbldescription = new QLabel();
+    lbldescription->setAlignment(Qt::AlignHCenter| Qt::AlignTop);
+    lbldescription->setWordWrap(true);
+
+    lbltitle = new QLabel();
+    lbltitle->setAlignment(Qt::AlignHCenter | Qt::AlignBottom);
+
     CBTeam = new QComboBox(this);
     CBMission = new QComboBox(this);
     CBCampaign = new QComboBox(this);
 
-    pageLayout->addWidget(CBTeam, 1, 1);
-    pageLayout->addWidget(CBCampaign, 2, 1);
-    pageLayout->addWidget(CBMission, 3, 1);
+    infoLayout->addWidget(btnPreview,0,1,2,1);
+    infoLayout->addWidget(lbltitle,0,2,1,2);
+    infoLayout->addWidget(lbldescription,1,2,1,2);
+
+    pageLayout->addLayout(infoLayout, 0, 0, 2, 3);
+    pageLayout->addWidget(CBTeam, 2, 1);
+    pageLayout->addWidget(CBCampaign, 3, 1);
+    pageLayout->addWidget(CBMission, 4, 1);
 
     BtnStartCampaign = new QPushButton(this);
     BtnStartCampaign->setFont(*font14);
     BtnStartCampaign->setText(QPushButton::tr("Go!"));
-    pageLayout->addWidget(BtnStartCampaign, 2, 2);
+    pageLayout->addWidget(BtnStartCampaign, 3, 2);
 
     return pageLayout;
 }
