@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2004-2012 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2004-2013 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,10 @@ class PageCampaign : public AbstractPage
     public:
         PageCampaign(QWidget* parent = 0);
 
+        QPushButton *btnPreview;
         QPushButton *BtnStartCampaign;
+        QLabel *lbldescription;
+        QLabel *lbltitle;
         QComboBox   *CBMission;
         QComboBox   *CBCampaign;
         QComboBox   *CBTeam;
