@@ -203,12 +203,23 @@ PageEditTeam::PageEditTeam(QWidget* parent) :
 {
     initPage();
 
-    QRegExp pngSuffix("\\.png$");
-
     m_playerHash = "0000000000000000000000000000000000000000";
+    m_loaded = false;
+}
 
+void PageEditTeam::lazyLoad()
+{
+    if(m_loaded) return;
+    m_loaded = true;
+    qDebug("[LAZINESS] PageEditTeam::lazyLoad()");
+
+    HatModel * hatsModel = DataManager::instance().hatModel();
+    for(int i = 0; i < HEDGEHOGS_PER_TEAM; i++)
+        HHHats[i]->setModel(hatsModel);
+
+
+    QRegExp pngSuffix("\\.png$");
     DataManager & dataMgr = DataManager::instance();
-
     QStringList list;
 
 
@@ -236,7 +247,7 @@ PageEditTeam::PageEditTeam(QWidget* parent) :
             pix = pix.copy(0, 0, 32, 32);
         QIcon icon(pix);
 
-        QString grave = QString(file).remove(pngSuffix);
+        QString grave = file.remove(pngSuffix);
 
         CBGrave->addItem(icon, grave);
     }
@@ -327,6 +338,8 @@ void PageEditTeam::testSound()
 void PageEditTeam::createTeam(const QString & name, const QString & playerHash)
 {
     m_playerHash = playerHash;
+    lazyLoad();
+
     HWTeam newTeam(name);
     loadTeam(newTeam);
 }
@@ -334,6 +347,8 @@ void PageEditTeam::createTeam(const QString & name, const QString & playerHash)
 void PageEditTeam::editTeam(const QString & name, const QString & playerHash)
 {
     m_playerHash = playerHash;
+    lazyLoad();
+
     HWTeam team(name);
     team.loadFromFile();
     loadTeam(team);
