@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2004-2012 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2004-2013 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,11 @@ class PageNetServer : public AbstractPage
 
         QPushButton *BtnStart;
         QPushButton *BtnDefault;
+        QPushButton *BtnShare;
         QLabel *labelSD;
-        QLineEdit *leServerDescr;
         QLabel *labelPort;
+        QLabel *labelURL;
+        QLineEdit *leServerDescr;
         QSpinBox *sbPort;
 
     protected:
@@ -42,6 +44,7 @@ class PageNetServer : public AbstractPage
 
     private slots:
         void setDefaultPort();
+        void copyUrl();
 };
 
 #endif
