@@ -34,7 +34,7 @@
 
 #include <string>
 
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 #define WINVER 0x0500
 #include <windows.h>
 #else
@@ -42,7 +42,7 @@
 #include <sys/types.h>
 #endif
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 #include <sys/sysctl.h>
 #ifndef _SC_NPROCESSORS_ONLN
 #define _SC_NPROCESSORS_ONLN 58
@@ -207,7 +207,7 @@ void FeedbackDialog::GenerateSpecs()
     QString processor_name = "Processor: ";
 
     // platform specific code
-#ifdef Q_WS_MACX
+#ifdef Q_OS_MACX
     number_of_cores += QString::number(sysconf(_SC_NPROCESSORS_ONLN)) + "\n";
 
     uint64_t memsize;
@@ -240,7 +240,7 @@ void FeedbackDialog::GenerateSpecs()
         default: os_version += "\"Unknown version\"\n"; break;
     }
 #endif
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     SYSTEM_INFO sysinfo;
     GetSystemInfo(&sysinfo);
     number_of_cores += QString::number(sysinfo.dwNumberOfProcessors) + "\n";
@@ -257,27 +257,24 @@ void FeedbackDialog::GenerateSpecs()
         case QSysInfo::WV_2003: os_version += "Windows Server 2003\n"; break;
         case QSysInfo::WV_VISTA: os_version += "Windows Vista\n"; break;
         case QSysInfo::WV_WINDOWS7: os_version += "Windows 7\n"; break;
-        //case QSysInfo::WV_WINDOWS8: os_version += "Windows 8\n"; break; //QT 5+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+        case QSysInfo::WV_WINDOWS8: os_version += "Windows 8\n"; break;
+#endif
         default: os_version += "Windows (Unknown version)\n"; break;
     }
     kernel_line += "Windows kernel\n";
 #endif
-#ifdef Q_WS_X11
+#ifdef Q_OS_LINUX
     number_of_cores += QString::number(sysconf(_SC_NPROCESSORS_ONLN)) + "\n";
-    long pages = sysconf(_SC_PHYS_PAGES),
-/*
-#ifndef Q_OS_FREEBSD
-         available_pages = sysconf(_SC_AVPHYS_PAGES),
-#else
-         available_pages = 0,
-#endif*/
-    page_size = sysconf(_SC_PAGE_SIZE);
-    total_ram += QString::number(pages*page_size/1024/1024) + " MB\n";
+    quint32 pages = sysconf(_SC_PHYS_PAGES);
+    quint32 page_size = sysconf(_SC_PAGE_SIZE);
+    quint32 total = pages * page_size / 1024 / 1024;
+    total_ram += QString::number(total) + " MB\n";
     os_version += "GNU/Linux or BSD\n";
 #endif
 
     // uname -a
-#if defined(Q_WS_X11) || defined(Q_WS_MACX)
+#if defined(Q_OS_LINUX) || defined(Q_OS_MAC)
     QProcess *process = new QProcess();
     QStringList arguments = QStringList("-a");
     process->start("uname", arguments);
@@ -286,7 +283,7 @@ void FeedbackDialog::GenerateSpecs()
     delete process;
 #endif
 
-#if (!defined(Q_WS_MACX) && defined(__i386__)) || defined(__x86_64__)
+#if (defined(Q_OS_WIN) && defined(__i386__)) || defined(__x86_64__)
     // cpu info
     quint32 registers[4];
     quint32 i;
@@ -432,7 +429,7 @@ void FeedbackDialog::LoadCaptchaImage()
 
 void FeedbackDialog::finishedSlot(QNetworkReply* reply)
 {
-    if (reply && reply->error() == QNetworkReply::NoError)
+    if (reply->error() == QNetworkReply::NoError)
     {
             QMessageBox infoMsg(this);
             infoMsg.setIcon(QMessageBox::Information);
