@@ -321,6 +321,7 @@ QByteArray GameCFGWidget::getFullConfig() const
     bcfg << QString("e$healthdec %1").arg(schemeData(38).toInt()).toUtf8();
     bcfg << QString("e$ropepct %1").arg(schemeData(39).toInt()).toUtf8();
     bcfg << QString("e$getawaytime %1").arg(schemeData(40).toInt()).toUtf8();
+    bcfg << QString("e$worldedge %1").arg(schemeData(41).toInt()).toUtf8();
     bcfg << QString("e$template_filter %1").arg(pMapContainer->getTemplateFilter()).toUtf8();
     bcfg << QString("e$mapgen %1").arg(mapgen).toUtf8();
 
@@ -389,7 +390,10 @@ void GameCFGWidget::fullNetConfig()
 
     seedChanged(pMapContainer->getCurrentSeed());
     templateFilterChanged(pMapContainer->getTemplateFilter());
-    themeChanged(pMapContainer->getCurrentTheme());
+
+    QString t = pMapContainer->getCurrentTheme();
+    if(!t.isEmpty())
+        themeChanged(t);
 
     schemeChanged(GameSchemes->currentIndex());
     scriptChanged(Scripts->currentIndex());
