@@ -151,6 +151,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>GameUIConfig</name>
+    <message>
+        <source>Guest</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HWApplication</name>
     <message numerus="yes">
@@ -363,6 +370,19 @@ Please wait a few seconds and try again.</source>
         <source>This page requires an internet connection.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Guest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Room password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The room is protected with password.
+Please, enter the password:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -619,13 +639,6 @@ just enter your nickname.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>KB</name>
-    <message>
-        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>KeyBinder</name>
     <message>
@@ -635,19 +648,6 @@ just enter your nickname.</source>
 </context>
 <context>
     <name>LibavInteraction</name>
-    <message>
-        <source>Duration: %1m %2s
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Video: %1x%2, </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>%1 fps, </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Audio: </source>
         <translation type="unfinished"></translation>
@@ -656,6 +656,18 @@ just enter your nickname.</source>
         <source>unknown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Duration: %1m %2s</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video: %1x%2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 fps</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MapModel</name>
@@ -783,6 +795,18 @@ just enter your nickname.</source>
         <source>Eraser</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Polyline</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rectangle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ellipse</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageEditTeam</name>
@@ -889,6 +913,12 @@ just enter your nickname.</source>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
+    <message numerus="yes">
+        <source>(%1 %2)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageInGame</name>
@@ -1192,14 +1222,6 @@ just enter your nickname.</source>
         <source>Admin features</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Rules:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weapons:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message numerus="yes">
         <source>%1 players online</source>
         <translation type="unfinished">
@@ -1222,10 +1244,6 @@ just enter your nickname.</source>
         <source>Room state</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Clear filters</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Open server administration page</source>
         <translation type="unfinished"></translation>
@@ -1353,6 +1371,22 @@ just enter your nickname.</source>
         <source>Add an indestructible border along the bottom</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>None (Default)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wrap (World wraps)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bounce (Edges reflect)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sea (Edges connect to sea)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -1448,13 +1482,11 @@ just enter your nickname.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Date: %1
-</source>
+        <source>Date: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Size: %1
-</source>
+        <source>Size: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1587,6 +1619,38 @@ just enter your nickname.</source>
         <source>Frontend music</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Team</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable team tags by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable hedgehog tags by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Health</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable health tags by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Translucent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable translucent tags by default</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QComboBox</name>
@@ -1606,10 +1670,6 @@ just enter your nickname.</source>
         <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Any</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Disabled</source>
         <translation type="unfinished"></translation>
@@ -1808,10 +1868,6 @@ just enter your nickname.</source>
         <source>Explosives</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Tip: </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Quality</source>
         <translation type="unfinished"></translation>
@@ -1954,6 +2010,18 @@ Do you really want to quit?</source>
         <source>This setting will be effective at next restart.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Tip: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Displayed tags above hogs and translucent tags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>World Edge</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -1976,10 +2044,6 @@ Do you really want to quit?</source>
         <source>Hedgewars %1</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>-r%1 (%2)</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QMessageBox</name>
@@ -2194,6 +2258,13 @@ Not all players are ready.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>No description available</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QPushButton</name>
     <message>
@@ -2309,7 +2380,7 @@ Not all players are ready.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Click to copy your unique server URL in your clipboard. Send this link to your friends ands and they will be able to join you.</source>
+        <source>Click to copy your unique server URL to your clipboard. Send this link to your friends and they will be able to join you.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -2331,6 +2402,10 @@ Not all players are ready.</source>
         <source>Create room</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>set password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RoomsListModel</name>
@@ -2378,6 +2453,10 @@ Not all players are ready.</source>
         <source>Hand-drawn</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Script</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SeedPrompt</name>
@@ -2444,13 +2523,6 @@ Error code: %2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>TeamShowWidget</name>
-    <message>
-        <source>%1&apos;s team</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>ThemePrompt</name>
     <message>
@@ -3046,4 +3118,127 @@ Error code: %2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>server</name>
+    <message>
+        <source>Restricted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not room master</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Corrupted hedgehogs info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>too many teams</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>too many hedgehogs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>There&apos;s already a team with same name in the list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>round in progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>restricted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>REMOVE_TEAM: no such team</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not team owner!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Less than two clans!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Illegal room name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Room with such name already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nickname already chosen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Illegal nickname</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Protocol already known</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bad number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nickname is already in use</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No checker rights</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Authentication failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>60 seconds cooldown after kick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>kicked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ping timeout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>bye</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No such room</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Room version incompatible to your hedgewars version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Joining restricted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Registered users only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You are banned in this room</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Empty config entry</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
