@@ -4,25 +4,25 @@ locale = {
 --      ["..."] = "",
 --      ["011101000"] = "", -- A_Classic_Fairytale:dragon
 --      ["011101001"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
---      ["30 minutes later..."] = "", -- A_Classic_Fairytale:shadow
---      ["About a month ago, a cyborg came and told us that you're the cannibals!"] = "", -- A_Classic_Fairytale:enemy
---      ["Accuracy Bonus!"] = "",
---      ["Ace"] = "", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_Rope_Knock_Challenge
---      ["Achievement Unlocked"] = "", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_That_Sinking_Feeling, Tumbler
---      ["A Classic Fairytale"] = "", -- A_Classic_Fairytale:first_blood
+      ["30 minutes later..."] = "30 minutos mais tarde...", -- A_Classic_Fairytale:shadow
+      ["About a month ago, a cyborg came and told us that you're the cannibals!"] = "Há cerca de um mês, um ciborgue veio e nos contou que vocês são os canibais!", -- A_Classic_Fairytale:enemy
+      ["Accuracy Bonus!"] = "Bônus por acurácia",
+      ["Ace"] = "Ás", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_Rope_Knock_Challenge
+      ["Achievement Unlocked"] = "Conquista alcançada", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_That_Sinking_Feeling, Tumbler
+      ["A Classic Fairytale"] = "Um conto de fadas clássico", -- A_Classic_Fairytale:first_blood
 --      ["???"] = "", -- A_Classic_Fairytale:backstab
---      ["Actually, you aren't worthy of life! Take this..."] = "", -- A_Classic_Fairytale:shadow
---      ["A cy-what?"] = "", -- A_Classic_Fairytale:enemy
+      ["Actually, you aren't worthy of life! Take this..."] = "Na verdade, você não merece viver! Tome isso...", -- A_Classic_Fairytale:shadow
+      ["A cy-what?"] = "Um cib... o quê?", -- A_Classic_Fairytale:enemy
 --      ["Adventurous"] = "", -- A_Classic_Fairytale:journey
---      ["Africa"] = "", -- Continental_supplies
---      ["After Leaks A Lot betrayed his tribe, he joined the cannibals..."] = "", -- A_Classic_Fairytale:first_blood
+      ["Africa"] = "África", -- Continental_supplies
+      ["After Leaks A Lot betrayed his tribe, he joined the cannibals..."] = "Depois que Vaza Demais traiu sua tribo, ele se juntou aos canibais...", -- A_Classic_Fairytale:first_blood
 --      ["After the shock caused by the enemy spy, Leaks A Lot and Dense Cloud went hunting to relax."] = "", -- A_Classic_Fairytale:shadow
 --      ["Again with the 'cannibals' thing!"] = "", -- A_Classic_Fairytale:enemy
---      ["a Hedgewars challenge"] = "", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_Rope_Knock_Challenge
---      ["a Hedgewars mini-game"] = "", -- Space_Invasion, The_Specialists
+      ["a Hedgewars challenge"] = "um desafio Hedgewars", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_Rope_Knock_Challenge
+      ["a Hedgewars mini-game"] = "um mini-jogo Hedgewars", -- Space_Invasion, The_Specialists
 	["Aiming Practice"] = "Pratique a sua pontaria", --Bazooka, Shotgun, SniperRifle
 --      ["A leap in a leap"] = "", -- A_Classic_Fairytale:first_blood
---      ["A little gift from the cyborgs"] = "", -- A_Classic_Fairytale:shadow
+      ["A little gift from the cyborgs"] = "Um pequeno presente dos ciborgues", -- A_Classic_Fairytale:shadow
 --      ["All gone...everything!"] = "", -- A_Classic_Fairytale:enemy
 --      ["All right, we just need to get to the other side of the island!"] = "", -- A_Classic_Fairytale:journey
 --      ["All walls touched!"] = "", -- WxW
@@ -32,8 +32,8 @@ locale = {
 --      ["Ammo is reset at the end of your turn."] = "",
 --      ["Ammo Maniac!"] = "",
 --      ["And how am I alive?!"] = "", -- A_Classic_Fairytale:enemy
---      ["And so happenned that Leaks A Lot failed to complete the challenge! He landed, pressured by shame..."] = "", -- A_Classic_Fairytale:first_blood
---      ["And so it began..."] = "", -- A_Classic_Fairytale:first_blood
+      ["And so happenned that Leaks A Lot failed to complete the challenge! He landed, pressured by shame..."] = "E acabou que Vaza Demais falhou em superar o desafio! Ele chegou em terra firme, pressionado pela vergonha...", -- A_Classic_Fairytale:first_blood
+      ["And so it began..."] = "E foi assim que começou...", -- A_Classic_Fairytale:first_blood
 --      ["...and so the cyborgs took over the world..."] = "", -- A_Classic_Fairytale:shadow
 --      ["And so they discovered that cyborgs weren't invulnerable..."] = "", -- A_Classic_Fairytale:journey
 --      ["And where's all the weed?"] = "", -- A_Classic_Fairytale:dragon
@@ -49,7 +49,7 @@ locale = {
 --      ["Asia"] = "", -- Continental_supplies
 --      ["Assault Team"] = "", -- A_Classic_Fairytale:backstab
 --      ["As the ammo is sparse, you might want to reuse ropes while mid-air.|"] = "", -- A_Classic_Fairytale:dragon
---      ["As the challenge was completed, Leaks A Lot set foot on the ground..."] = "", -- A_Classic_Fairytale:first_blood
+      ["As the challenge was completed, Leaks A Lot set foot on the ground..."] = "Como o desafio foi superado, Vaza Demais colocou os pés no chão...", -- A_Classic_Fairytale:first_blood
 --      ["As you can see, there is no way to get on the other side!"] = "", -- A_Classic_Fairytale:dragon
 --      ["Attack From Rope"] = "", -- WxW
 --      ["Australia"] = "", -- Continental_supplies
@@ -100,7 +100,7 @@ locale = {
 --      ["But you're cannibals. It's what you do."] = "", -- A_Classic_Fairytale:enemy
 --      ["But you said you'd let her go!"] = "", -- A_Classic_Fairytale:journey
 --      ["Call me Beep! Well, 'cause I'm such a nice...person!"] = "", -- A_Classic_Fairytale:family
---      ["Cannibals"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood
+      ["Cannibals"] = "Canibais", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood
 --      ["Cannibal Sentry"] = "", -- A_Classic_Fairytale:journey
 --      ["Cannibals?! You're the cannibals!"] = "", -- A_Classic_Fairytale:enemy
 --      ["CAPTURE THE FLAG"] = "",
@@ -115,11 +115,11 @@ locale = {
 --      ["Codename: Teamwork"] = "",
 --      ["Collateral Damage"] = "", -- A_Classic_Fairytale:journey
 --      ["Collateral Damage II"] = "", -- A_Classic_Fairytale:journey
---      ["Collect all the crates, but remember, our time in this life is limited!"] = "", -- A_Classic_Fairytale:first_blood
+      ["Collect all the crates, but remember, our time in this life is limited!"] = "Colete todas as caixas, mas lembre-se: nosso tempo nesta vida é limitado!", -- A_Classic_Fairytale:first_blood
 --      ["Collect or destroy all the health crates."] = "", -- User_Mission_-_RCPlane_Challenge
---      ["Collect the crate on the right.|Hint: Select the rope, [Up] or [Down] to aim, [Space] to fire, directional keys to move.|Ropes can be fired again in the air!"] = "", -- A_Classic_Fairytale:first_blood
---      ["Collect the crates within the time limit!|If you fail, you'll have to try again."] = "", -- A_Classic_Fairytale:first_blood
---      ["Come closer, so that your training may continue!"] = "", -- A_Classic_Fairytale:first_blood
+      ["Collect the crate on the right.|Hint: Select the rope, [Up] or [Down] to aim, [Space] to fire, directional keys to move.|Ropes can be fired again in the air!"] = "Pegue a caixa à direita.|Dica: Selecione a corda, [Cima] ou [Baixo] para mirar, [Espaço] para atirar, teclas direcionais para se mover.|Cordas podem ser disparadas novamente no ar!", -- A_Classic_Fairytale:first_blood
+      ["Collect the crates within the time limit!|If you fail, you'll have to try again."] = "Colete as caixas dentro do limite de tempo!|Se falhar, você terá que tentar de novo.", -- A_Classic_Fairytale:first_blood
+      ["Come closer, so that your training may continue!"] = "Aproxime-se, para que seu treinamento possa continuar!", -- A_Classic_Fairytale:first_blood
 --      ["Compete to use as few planes as possible!"] = "", -- User_Mission_-_RCPlane_Challenge
 --      ["Complete the track as fast as you can!"] = "",
 --      ["COMPLETION TIME"] = "", -- User_Mission_-_Rope_Knock_Challenge
@@ -151,10 +151,10 @@ locale = {
 --      ["Dense Cloud"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
 --      ["Dense Cloud must have already told them everything..."] = "", -- A_Classic_Fairytale:shadow
 --      ["Depleted Kamikaze!"] = "",
---      ["Destroy him, Leaks A Lot! He is responsible for the deaths of many of us!"] = "", -- A_Classic_Fairytale:first_blood
---      ["Destroy invaders to score points."] = "",
---      ["Destroy the targets!|Hint: Select the Shoryuken and hit [Space]|P.S. You can use it mid-air."] = "", -- A_Classic_Fairytale:first_blood
---      ["Destroy the targets!|Hint: [Up], [Down] to aim, [Space] to shoot"] = "", -- A_Classic_Fairytale:first_blood
+      ["Destroy him, Leaks A Lot! He is responsible for the deaths of many of us!"] = "Destrua-o, Vaza Demais! Ele é responsável pelas mortes de muitos de nós!", -- A_Classic_Fairytale:first_blood
+      ["Destroy invaders to score points."] = "Destrua os invasores para conseguir pontos.",
+      ["Destroy the targets!|Hint: Select the Shoryuken and hit [Space]|P.S. You can use it mid-air."] = "Destrua os alvos!|Dica: Selecione o Shoryuken e aperte [Espaço]|Obs.: Você pode usá-lo em pleno ar.", -- A_Classic_Fairytale:first_blood
+      ["Destroy the targets!|Hint: [Up], [Down] to aim, [Space] to shoot"] = "Destrua os alvos!|Dica: [Cima], [Baixo] para mirar, [Espaço] para atirar", -- A_Classic_Fairytale:first_blood
 --      ["Did anyone follow you?"] = "", -- A_Classic_Fairytale:united
 --      ["Did you see him coming?"] = "", -- A_Classic_Fairytale:shadow
 --      ["Did you warn the village?"] = "", -- A_Classic_Fairytale:shadow
@@ -224,10 +224,10 @@ locale = {
 --      ["Fire"] = "",
 --      ["Fire a mine: [Does what it says ~ Cant be dropped close to an enemy ~ 1 sec]"] = "", -- Continental_supplies
 --      ["First aid kits?!"] = "", -- A_Classic_Fairytale:united
---      ["First Blood"] = "", -- A_Classic_Fairytale:first_blood
+      ["First Blood"] = "Primeiro sangue", -- A_Classic_Fairytale:first_blood
 --      ["FIRST BLOOD MUTATES"] = "", -- Mutant
---      ["First Steps"] = "", -- A_Classic_Fairytale:first_blood
---      ["Flag captured!"] = "",
+      ["First Steps"] = "Primeiros passos", -- A_Classic_Fairytale:first_blood
+      ["Flag captured!"] = "Bandeira capturada!",
 --      ["Flag respawned!"] = "",
 --      ["Flag returned!"] = "",
 --      ["Flags, and their home base will be placed where each team ends their first turn."] = "",
@@ -550,7 +550,7 @@ locale = {
 --      ["Oh, silly me! I forgot that I'm the shaman."] = "", -- A_Classic_Fairytale:backstab
 --      ["Olive"] = "", -- A_Classic_Fairytale:united
 --      ["Omnivore"] = "", -- A_Classic_Fairytale:first_blood
---      ["Once upon a time, on an island with great natural resources, lived two tribes in heated conflict..."] = "", -- A_Classic_Fairytale:first_blood
+      ["Once upon a time, on an island with great natural resources, lived two tribes in heated conflict..."] = "Era uma vez, em uma ilha com ótimos recursos naturais, duas tribos que viviam em intenso conflito...", -- A_Classic_Fairytale:first_blood
 --      ["ONE HOG PER TEAM! KILLING EXCESS HEDGES"] = "", -- Mutant
 --      ["One tribe was peaceful, spending their time hunting and training, enjoying the small pleasures of life..."] = "", -- A_Classic_Fairytale:first_blood
 --      ["Oops...I dropped them."] = "", -- A_Classic_Fairytale:united
