@@ -26,10 +26,10 @@ locale = {
 --      ["All gone...everything!"] = "", -- A_Classic_Fairytale:enemy
 --      ["All right, we just need to get to the other side of the island!"] = "", -- A_Classic_Fairytale:journey
 --      ["All walls touched!"] = "", -- WxW
-	["Ammo Depleted!"] = "Munition erschöpft!",
-	["ammo extended!"] = "Munition aufgestockt!",
-	["Ammo is reset at the end of your turn."] = "Munition wird am Ende des Spielzuges zurückgesetzt.",
-	["Ammo Maniac!"] = "Munitionsverrückter!",
+	["Ammo Depleted!"] = "Mermi Bitti!",
+	["ammo extended!"] = "mermi genişletildi!",
+	["Ammo is reset at the end of your turn."] = "Mermi turunun sonunda sıfırlanır.",
+	["Ammo Maniac!"] = "Mermi Manyağı!",
 	["Ammo"] = "Mermi",
 --      ["And how am I alive?!"] = "", -- A_Classic_Fairytale:enemy
 --      ["And so happenned that Leaks A Lot failed to complete the challenge! He landed, pressured by shame..."] = "", -- A_Classic_Fairytale:first_blood
@@ -53,35 +53,35 @@ locale = {
 --      ["As you can see, there is no way to get on the other side!"] = "", -- A_Classic_Fairytale:dragon
 --      ["Attack From Rope"] = "", -- WxW
 --      ["Australia"] = "", -- Continental_supplies
-	["Available points remaining: "] = "Verfügbare Punkte verbleibend:",
+	["Available points remaining: "] = "Halan kullanılabilir puanlar: ",
 --      ["Back Breaker"] = "", -- A_Classic_Fairytale:backstab
 --      ["Back in the village, after telling the villagers about the threat..."] = "", -- A_Classic_Fairytale:united
 --      ["[Backspace]"] = "",
 --      ["Backstab"] = "", -- A_Classic_Fairytale:backstab
 --      ["Bad Team"] = "", -- User_Mission_-_The_Great_Escape
 --      ["Bamboo Thicket"] = "",
-	["Barrel Eater!"] = "Fassfresser!",
-	["Barrel Launcher"] = "Fasswerfer",
+	["Barrel Eater!"] = "Varilsever!",
+	["Barrel Launcher"] = "Varil Patlatıcı",
 --      ["Baseballbat"] = "", -- Continental_supplies
-	["Bat balls at your enemies and|push them into the sea!"] = "Schlage Bälle auf deine Widersacher|und lass sie ins Meer fallen!",
-	["Bat your opponents through the|baskets and out of the map!"] = "Schlage deine Widersacher durch|die Körbe und aus der Karte hinaus!",
-	["Bazooka Training"] = "Bazooka-Training",
+	["Bat balls at your enemies and|push them into the sea!"] = "Düşmanlarına sopayla vur|ve denize dök!",
+	["Bat your opponents through the|baskets and out of the map!"] = "Düşmanlarını sepetlere vurarak|harita dışına at!",
+	["Bazooka Training"] = "Roketatar Eğitimi",
 --      ["Beep Loopers"] = "", -- A_Classic_Fairytale:queen
-	["Best laps per team: "] = "Beste Rundenzeiten pro Team: ",
-	["Best Team Times: "] = "Beste Team-Zeiten: ",
+	["Best laps per team: "] = "Her takım için en iyi tur: ",
+	["Best Team Times: "] = "En İyi Takım Süresi: ",
 --      ["Beware, though! If you are slow, you die!"] = "", -- A_Classic_Fairytale:dragon
 --      ["Biomechanic Team"] = "", -- A_Classic_Fairytale:family
 --      ["Blender"] = "", -- A_Classic_Fairytale:family
 --      ["Bloodpie"] = "", -- A_Classic_Fairytale:backstab
 --      ["Bloodrocutor"] = "", -- A_Classic_Fairytale:shadow
 --      ["Bloodsucker"] = "", -- A_Classic_Fairytale:shadow
-	["Bloody Rookies"] = "Blutige Anfänger", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree
+	["Bloody Rookies"] = "Kanlı Acemiler", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree
 --      ["Bone Jackson"] = "", -- A_Classic_Fairytale:backstab
 --      ["Bonely"] = "", -- A_Classic_Fairytale:shadow
 	["Boom!"] = "Bumm!",
-	["BOOM!"] = "KABUMM!",
-	["Boss defeated!"] = "Boss wurde besiegt!",
-	["Boss Slayer!"] = "Boss-Töter!",
+	["BOOM!"] = "BUMM!",
+	["Boss defeated!"] = "Patron öldürüldü!",
+	["Boss Slayer!"] = "Patron Katili!",
 --      ["Brain Blower"] = "", -- A_Classic_Fairytale:journey
 --      ["Brainiac"] = "", -- A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
 --      ["Brainila"] = "", -- A_Classic_Fairytale:united
@@ -89,7 +89,7 @@ locale = {
 --      ["Brain Teaser"] = "", -- A_Classic_Fairytale:backstab
 --      ["Brutal Lily"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil
 --      ["Brutus"] = "", -- A_Classic_Fairytale:backstab
-    ["Build a track and race."] = "Konstruiere eine Strecke und mach ein Wettrennen.",
+    ["Build a track and race."] = "Bir yol inşa et ve yarış.",
 --      ["Bullseye"] = "", -- A_Classic_Fairytale:dragon
 --      ["But it proved to be no easy task!"] = "", -- A_Classic_Fairytale:dragon
 --      ["But that's impossible!"] = "", -- A_Classic_Fairytale:backstab
@@ -103,16 +103,16 @@ locale = {
 --      ["Cannibals"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood
 --      ["Cannibal Sentry"] = "", -- A_Classic_Fairytale:journey
 --      ["Cannibals?! You're the cannibals!"] = "", -- A_Classic_Fairytale:enemy
-	["CAPTURE THE FLAG"] = "EROBERE DIE FAHNE",
-	["Careless"] = "Achtlos",
+	["CAPTURE THE FLAG"] = "BAYRAĞI YAKALA",
+	["Careless"] = "Dikkatsiz",
 --      ["Carol"] = "", -- A_Classic_Fairytale:family
 --      ["CHALLENGE COMPLETE"] = "", -- User_Mission_-_RCPlane_Challenge
-	["Change Weapon"] = "Waffenwechsel",
+	["Change Weapon"] = "Silahı Değiştir",
 --      ["Choose your side! If you want to join the strange man, walk up to him.|Otherwise, walk away from him. If you decide to att...nevermind..."] = "", -- A_Classic_Fairytale:shadow
-	["Clumsy"] = "Hoppla",
+	["Clumsy"] = "Sakar",
 --      ["Cluster Bomb MASTER!"] = "", -- Basic_Training_-_Cluster_Bomb
 --      ["Cluster Bomb Training"] = "", -- Basic_Training_-_Cluster_Bomb
-	["Codename: Teamwork"] = "Code-Name: Teamwork",
+	["Codename: Teamwork"] = "Kodadı: Takım Çalışması",
 --      ["Collateral Damage"] = "", -- A_Classic_Fairytale:journey
 --      ["Collateral Damage II"] = "", -- A_Classic_Fairytale:journey
 --      ["Collect all the crates, but remember, our time in this life is limited!"] = "", -- A_Classic_Fairytale:first_blood
@@ -121,16 +121,16 @@ locale = {
 --      ["Collect the crates within the time limit!|If you fail, you'll have to try again."] = "", -- A_Classic_Fairytale:first_blood
 --      ["Come closer, so that your training may continue!"] = "", -- A_Classic_Fairytale:first_blood
 --      ["Compete to use as few planes as possible!"] = "", -- User_Mission_-_RCPlane_Challenge
-	["Complete the track as fast as you can!"] = "Durchlaufe die Strecke so schnell du kannst!",
+	["Complete the track as fast as you can!"] = "Yolu mümkün olduğunca hızlı tamamla!",
 --      ["COMPLETION TIME"] = "", -- User_Mission_-_Rope_Knock_Challenge
 --      ["Configuration accepted."] = "", -- WxW
 --      ["Congratulations"] = "", -- Basic_Training_-_Rope
-	["Congratulations!"] = "Gratulation!",
+	["Congratulations!"] = "Tebrikler!",
 --      ["Congratulations! You needed only half of time|to eliminate all targets."] = "", -- Basic_Training_-_Cluster_Bomb
 --      ["Congratulations! You've completed the Rope tutorial! |- Tutorial ends in 10 seconds!"] = "", -- Basic_Training_-_Rope
-	["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Gratulation! Du hast alle Ziele innerhalb der|verfügbaren Zeit ausgeschaltet.", --Bazooka, Shotgun, SniperRifle
+	["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Tebrikler! Tüm hedefleri|belirtilen sürede yendin.", --Bazooka, Shotgun, SniperRifle
 --      ["Continental supplies"] = "", -- Continental_supplies
-	["Control pillars to score points."] = "Kontrolliere die Säulen um Punkte zu erhalten.",
+	["Control pillars to score points."] = "Puan toplamak için sütunları denetle.",
 --      ["Corporationals"] = "", -- A_Classic_Fairytale:queen
 --      ["Corpsemonger"] = "", -- A_Classic_Fairytale:shadow
 --      ["Corpse Thrower"] = "", -- A_Classic_Fairytale:epil
@@ -138,21 +138,21 @@ locale = {
 	["Cybernetic Empire"] = "Kybernetisches Imperium",
 --      ["Cyborg. It's what the aliens call themselves."] = "", -- A_Classic_Fairytale:enemy
 --      ["Dahmer"] = "", -- A_Classic_Fairytale:backstab
-	["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "VERDAMMT, REKRUT! RUNTER VON MEINEM KOPF!",
-	["DAMMIT, ROOKIE!"] = "VERDAMMT, REKRUT!",
+	["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "LANET OLSUN ACEMİ! DEFOL BAŞIMDAN!",
+	["DAMMIT, ROOKIE!"] = "LANET OLSUN ACEMİ!",
 --      ["Dangerous Ducklings"] = "",
-	["Deadweight"] = "Gravitus",
+	["Deadweight"] = "Graviton",
 --      ["Defeat the cannibals"] = "", -- A_Classic_Fairytale:backstab
 --      ["Defeat the cannibals!|"] = "", -- A_Classic_Fairytale:united
 --      ["Defeat the cannibals!|Grenade hint: set the timer with [1-5], aim with [Up]/[Down] and hold [Space] to set power"] = "", -- A_Classic_Fairytale:shadow
 --      ["Defeat the cyborgs!"] = "", -- A_Classic_Fairytale:enemy
 --      ["Defend yourself!|Hint: You can get tips on using weapons by moving your mouse over them in the weapon selection menu"] = "", -- A_Classic_Fairytale:shadow
-	["Demolition is fun!"] = "Zerstörung macht Spaß!",
+	["Demolition is fun!"] = "Yok etmek eğlencelidir!",
 --      ["Dense Cloud"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
 --      ["Dense Cloud must have already told them everything..."] = "", -- A_Classic_Fairytale:shadow
-	["Depleted Kamikaze!"] = "Munitionsloses Kamikaze!",
+	["Depleted Kamikaze!"] = "Boşa yapılmış Kamikaze!",
 --      ["Destroy him, Leaks A Lot! He is responsible for the deaths of many of us!"] = "", -- A_Classic_Fairytale:first_blood
-	["Destroy invaders to score points."] = "Zerstöre die Angreifer um Punkte zu erhalten.",
+	["Destroy invaders to score points."] = "Puan kazanmak için istilacıları yok et.",
 --      ["Destroy the targets!|Hint: Select the Shoryuken and hit [Space]|P.S. You can use it mid-air."] = "", -- A_Classic_Fairytale:first_blood
 --      ["Destroy the targets!|Hint: [Up], [Down] to aim, [Space] to shoot"] = "", -- A_Classic_Fairytale:first_blood
 --      ["Did anyone follow you?"] = "", -- A_Classic_Fairytale:united
@@ -172,7 +172,7 @@ locale = {
 --      ["Drills"] = "", -- A_Classic_Fairytale:backstab
 --      ["Drone Hunter!"] = "",
 --      ["Drop a bomb: [drop some heroic wind that will turn into a bomb on impact]"] = "", -- Continental_supplies
-	["Drowner"] = "Absäufer",
+	["Drowner"] = "Boğulucu",
 --      ["Dude, all the plants are gone!"] = "", -- A_Classic_Fairytale:family
 --      ["Dude, can you see Ramon and Spiky?"] = "", -- A_Classic_Fairytale:journey
 --      ["Dude, that's so cool!"] = "", -- A_Classic_Fairytale:backstab
@@ -182,15 +182,15 @@ locale = {
 --      ["Dude, wow! I just had the weirdest high!"] = "", -- A_Classic_Fairytale:backstab
 --      ["Duration"] = "", -- Continental_supplies
 --      ["Dust storm: [Deals 20 damage to all enemies in the circle]"] = "", -- Continental_supplies
-	["Each turn you get 1-3 random weapons"] = "Du bekommst jede Runde 1-3 zufällig gewählte Waffen",
-	["Each turn you get one random weapon"] = "Du bekommst jede Runde eine zufällig gewählte Waffe.",
+	["Each turn you get 1-3 random weapons"] = "Her turda 1-3 rastgele silah alacaksın",
+	["Each turn you get one random weapon"] = "Her turda bir adet rastgele silah alacaksın",
 --      ["Eagle Eye"] = "", -- A_Classic_Fairytale:backstab
 --      ["Eagle Eye: [Blink to the impact ~ one shot]"] = "", -- Continental_supplies
 --      ["Ear Sniffer"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:epil
 --      ["Elderbot"] = "", -- A_Classic_Fairytale:family
 --      ["Elimate your captor."] = "", -- User_Mission_-_The_Great_Escape
-	["Eliminate all enemies"] = "Vernichte alle Gegner",
-	["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Eliminiere alle Ziele bevor die Zeit ausläuft.|Du hast in dieser Mission unbegrenzte Munition.", --Bazooka, Shotgun, SniperRifle
+	["Eliminate all enemies"] = "Tüm düşmanı yoket",
+	["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Süren dolmadan tüm hedefleri yoket.|Bu görevde sınırsız mermin var.", --Bazooka, Shotgun, SniperRifle
 --      ["Eliminate enemy hogs and take their weapons."] = "", -- Highlander
 	["Eliminate Poison before the time runs out"] = "Neutralisiere das Gift bevor die Zeit abgelaufen ist",
 	["Eliminate the Blue Team"] = "Lösche das Blaue Team aus",
