@@ -208,7 +208,7 @@ locale = {
 --      ["Everything looks OK..."] = "", -- A_Classic_Fairytale:enemy
 --      ["Exactly, man! That was my dream."] = "", -- A_Classic_Fairytale:backstab
 --      ["Eye Chewer"] = "", -- A_Classic_Fairytale:journey
---      ["FAG"] = "", -- Mutant
+--      ["INSANITY"] = "", -- Mutant
 --      ["Family Reunion"] = "", -- A_Classic_Fairytale:family
         ["Fastest lap: "] = "Найшвидша партія: ",
         ["Feeble Resistance"] = "Жалюгідні Повстанці",
@@ -287,7 +287,8 @@ locale = {
 --      ["Hannibal"] = "", -- A_Classic_Fairytale:epil
         [" Hapless Hogs left!"] = " Нещасних Їжаків лишилось!",
         ["Hapless Hogs"] = "Нещасні Їжаки",
---      [" HAS MUTATED\" )"] = "", -- 
+
+--      [" HAS MUTATED"] = "", -- Mutant
 --      ["Hatless Jerry"] = "", -- A_Classic_Fairytale:queen
 --      ["Have no illusions, your tribe is dead, indifferent of your choice."] = "", -- A_Classic_Fairytale:shadow
 --      ["Have we ever attacked you first?"] = "", -- A_Classic_Fairytale:enemy
@@ -330,7 +331,7 @@ locale = {
         ["Hmmm..."] = "Хмм...",
 --      ["Hogminator"] = "", -- A_Classic_Fairytale:family
 --      ["Hogs in sight!"] = "", -- Continental_supplies
---      ["HOLY SHIT!"] = "", -- Mutant
+--      ["HOLY SHYTE!"] = "", -- Mutant
 --      ["Honest Lee"] = "", -- A_Classic_Fairytale:enemy
         ["Hooray!"] = "Урааа!",
 --      ["Hostage Situation"] = "", -- A_Classic_Fairytale:family
@@ -364,7 +365,7 @@ locale = {
 --      ["If you get stuck, use your Desert Eagle or restart the mission!|"] = "", -- A_Classic_Fairytale:journey
 --      ["If you know what I mean..."] = "", -- A_Classic_Fairytale:shadow
 --      ["If you say so..."] = "", -- A_Classic_Fairytale:shadow
---      ["If you wish to restart the course, hold [Precise] while your turn ends (e.g with Skip)"] = "", -- 
+
 --      ["I guess you'll have to kill them."] = "", -- A_Classic_Fairytale:dragon
 --      ["I have come to make you an offering..."] = "", -- A_Classic_Fairytale:shadow
 --      ["I have no idea where that mole disappeared...Can you see it?"] = "", -- A_Classic_Fairytale:shadow
@@ -563,11 +564,12 @@ locale = {
         ["Pathetic Resistance"] = "Жалюгідний Опір", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock
 --      ["Perfect! Now try to get the next crate without hurting yourself!"] = "", -- A_Classic_Fairytale:first_blood
         ["Per-Hog Ammo"] = "Боєприпаси на їжака",
---      ["- Per team weapons|- 9 weaponschemes|- Unique new weapons| |Select continent first round with the Weapon Menu or by ([switch/tab]=Increase,[presice/left shift]=Decrease)"] = "", -- 
+--      ["- Per team weapons|- 9 weaponschemes|- Unique new weapons| |Select continent first round with the Weapon Menu or by ([switch/tab]=Increase,[precise/left shift]=Decrease) on Skip|Some weapons have a second option. Find them with [switch/tab]"] = "", -- Continental_supplies
+
 --      ["Pfew! That was close!"] = "", -- A_Classic_Fairytale:shadow
 --      ["Piñata bullet: [Contains some sweet candy!]"] = "", -- Continental_supplies
 --      ["Pings left:"] = "", -- Space_Invasion
-        ["Place more waypoints using [ENTER]"] = "Розмістіть більше точок шляху за допомогою [Enter]",
+
         ["Place more waypoints using the 'Air Attack' weapon."] = "Розмістіть більше точок шляху використавши зброю 'Повітряна Атака'.",
 --      ["Planes Used:"] = "", -- User_Mission_-_RCPlane_Challenge
 --      ["Planes Used"] = "", -- User_Mission_-_RCPlane_Challenge
@@ -818,7 +820,7 @@ locale = {
 --      ["Use it wisely!"] = "", -- A_Classic_Fairytale:dragon
 --      ["Use it with precaution!"] = "", -- A_Classic_Fairytale:first_blood
         ["User Challenge"] = "Дуель між користувачами",
---      ["Use the parachute ([Space] while in air)"] = "", -- 
+
 --      ["Use the portal gun to get to the next crate, then use the new gun to get to the final destination!|"] = "", -- A_Classic_Fairytale:dragon
 --      ["Use the rope to get on the head of the mole, young one!"] = "", -- A_Classic_Fairytale:first_blood
 --      ["Use the rope to knock your enemies to their doom."] = "", -- User_Mission_-_Rope_Knock_Challenge
